# Shoggoth
## Card creation software for Arkham Horror: The Card Game

Status: Under development. Not stable, nor feature complete yet.

Shoggoth is ultimately just a piece of software that puts images and text on top of each other.
However, features a sensible "fallback" system that makes it easy to define new cards in very few rules.

Features to come:
* Viewer mode: Shoggoth will launch a small window that monitors a single file, and shows you the last card that you made edits to. This makes it easy to use a text editor to edit the raw json.
* Editor mode: Similar to other software, such as Strange Eons, a complete editor for users to create cards according to existing templates.
* Enforce good behavior: Encounter sets can only be added to expansions, and encounter cards can only be added to encounter sets. THis makes it easier to know that you've done everything right.
* Easy exporting: With a very simple data structure, comes very simple exporting. Export to PDF for TTS, Arkham.build or ArkhamCards in a single click.
* Easy sharing: Have shoggoth move all required images, along with all the data, into a single zip folder for easy sharing with your publisher.

You can incentivise the further development of Shoggoth (and other AH:TCG software and content) by donating on [Patreon](https://patreon.com/tokeeto) or [Ko-Fi](https://ko-fi.com/tokeeto).
